@@ -80,9 +80,9 @@ def status_by_versioned_type_name() -> Dict[str, str]:
         "g.node.instance.gt.000": "Pending",
         "gw.cert.id.000": "Active",
         "heartbeat.a.100": "Pending",
-        "initial.tadeed.algo.create.000": "Pending",
-        "initial.tadeed.algo.optin.002": "Pending",
-        "initial.tadeed.algo.transfer.000": "Pending",
+        "initial.tadeed.algo.create.000": "Active",
+        "initial.tadeed.algo.optin.002": "Active",
+        "initial.tadeed.algo.transfer.000": "Active",
         "ready.001": "Pending",
         "sim.timestep.000": "Pending",
         "super.starter.000": "Pending",
