@@ -4,9 +4,12 @@ from gridworks.enums.core_g_node_role import CoreGNodeRole
 from gridworks.enums.g_node_role import GNodeRole
 from gridworks.enums.g_node_status import GNodeStatus
 from gridworks.enums.gni_status import GniStatus
+from gridworks.enums.market_price_unit import MarketPriceUnit
+from gridworks.enums.market_quantity_unit import MarketQuantityUnit
 from gridworks.enums.market_type_name import MarketTypeName
 from gridworks.enums.message_category import MessageCategory
 from gridworks.enums.message_category_symbol import MessageCategorySymbol
+from gridworks.enums.recognized_currency_unit import RecognizedCurrencyUnit
 from gridworks.enums.strategy_name import StrategyName
 from gridworks.enums.supervisor_container_status import SupervisorContainerStatus
 from gridworks.enums.universe_type import UniverseType
@@ -18,9 +21,12 @@ __all__ = [
     "GNodeRole",
     "GNodeStatus",
     "GniStatus",
+    "MarketPriceUnit",
+    "MarketQuantityUnit",
     "MarketTypeName",
     "MessageCategory",
     "MessageCategorySymbol",
+    "RecognizedCurrencyUnit",
     "StrategyName",
     "SupervisorContainerStatus",
     "UniverseType",
